@@ -410,20 +410,17 @@ class PostgresqlService(MysqlService):
 
     def drop_table(self, table):
         try:
-            self.__connect()
-            df_tables = pd.read_sql_query("select * from pg_tables where schemaname = 'public'", con=self.conn)
-            tables = list(df_tables['tablename'])
-            if table in tables:
-                table = '\"' + table + '\"'
-                sql = 'drop table {}'.format(table)
-                cusor = self.conn.cursor()
-                cusor.execute(sql)
-                self.conn.commit()
-                cusor.close()
-                logging.debug('数据表删除成功！')
-            else:
-                logging.debug("not exists")
+            if self.conn is None:
+                self.__connect()
+            sql = 'drop table if exists "{}"'.format(table)
+            cusor = self.conn.cursor()
+            res = cusor.execute(sql)
+            self.conn.commit()
+            cusor.close()
+            # logging.debug('数据删除成功！')
         except Exception as e:
             traceback.print_exc()
+            logging.warning('while excute droppping {}'.format(table))
             self.close()
+            raise e
 
